==> haskell-stm-containers-1.2.1.1-124-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-86Il8Zl0y3y9pRWBbzkv1j
key:                  stm-containers-1.2.1.1-86Il8Zl0y3y9pRWBbzkv1j
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  ee2f98c303f3ca548624f27262d6e8c7
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-86Il8Zl0y3y9pRWBbzkv1j
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-FoBSiftVWcT4t8fgfUqevd
    focus-1.0.3.2-9UG6aWIJYQU1dpGJUMaXsH
    hashable-1.4.4.0-HF0gObldLcB4LirfpxeD3R
    list-t-1.0.5.7-Kce3kPVfPFH8fgauyBPiZn
    stm-hamt-1.2.1.1-Gi9jaHvRBFT4jUoEqON9Xf transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-containers-1.2.1.1-147-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-JkQzghCiirYSX2KXoZcs5
key:                  stm-containers-1.2.1.1-JkQzghCiirYSX2KXoZcs5
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  b3856671728eeca0b1ceff530d87747b
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-JkQzghCiirYSX2KXoZcs5
depends:
    base-4.17.2.1 deferred-folds-0.9.18.7-3yfE7C237Z7EaNudx50gxt
    focus-1.0.3.2-8hrsVfu9SCyGKwxAyYgRHl
    hashable-1.4.7.0-KrA5CwhmktQ6Qu5a4JCqq7
    list-t-1.0.5.7-GdSuNSaT7D1HbJEvfXY0bP
    stm-hamt-1.2.1.1-KFxLb5UNq5UDX5THhMshVc transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
